==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/mapping/vcard/BirthdayMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.mapping.vcard;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

public class BirthdayMapping extends SimpleFieldMapping {
	private final static String[] DATE_FORMATS = { "yyyyMMdd", "yyyy-MM-dd'T'HH:mm:ss'Z'" };
	private final static String OUTGOING_DATE_FORMAT = DATE_FORMATS[DATE_FORMATS.length - 1];

	public BirthdayMapping(String prop, String... oxFields) {
		super(prop, null, null, oxFields);
	}

	@Override
	protected Object convertToDataObjectValue(String value) {
		if (value == null || value.trim().length() == 0)
			return null;
		for (String format : DATE_FORMATS) {
			try {
				return getFormat(format).parse(value).getTime();
			} catch (ParseException e) {
			}
		}
		throw new IllegalArgumentException(value + " is not in a valid birthday format");
	}

	@Override
	protected String convertToVCardValue(Object value) {
		if (value instanceof Number)
			return createDateString(new Date(((Number) value).longValue()));
		if (value instanceof Date)
			return createDateString((Date) value);
		return null;
	}

	private String createDateString(Date value) {
		return getFormat(OUTGOING_DATE_FORMAT).format(value);
	}

	private SimpleDateFormat getFormat(String pattern) {
		SimpleDateFormat result = new SimpleDateFormat(pattern);
		result.setTimeZone(TimeZone.getTimeZone("GMT"));
		return result;
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.syncml/src/com/openexchange/usm/syncml/mapping/vcard/BirthdayMapping.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.syncml.mapping.vcard;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

public class BirthdayMapping extends SimpleFieldMapping {
	private static final String[] DATE_FORMATS = { "yyyyMMdd", "yyyy-MM-dd'T'HH:mm:ss'Z'" };
	private static final String OUTGOING_DATE_FORMAT = DATE_FORMATS[DATE_FORMATS.length - 1];

	public BirthdayMapping(String prop, String... oxFields) {
		super(prop, null, null, oxFields);
	}

	@Override
	protected Object convertToDataObjectValue(String value) {
		if (value == null || value.trim().length() == 0)
			return null;
		for (String format : DATE_FORMATS) {
			try {
				return getFormat(format).parse(value).getTime();
			} catch (ParseException ignored) {
			}
		}
		throw new IllegalArgumentException(value + " is not in a valid birthday format");
	}

	@Override
	protected String convertToVCardValue(Object value) {
		if (value instanceof Number)
			return createDateString(new Date(((Number) value).longValue()));
		if (value instanceof Date)
			return createDateString((Date) value);
		return null;
	}

	private String createDateString(Date value) {
		return getFormat(OUTGOING_DATE_FORMAT).format(value);
	}

	private SimpleDateFormat getFormat(String pattern) {
		SimpleDateFormat result = new SimpleDateFormat(pattern);
		result.setTimeZone(TimeZone.getTimeZone("GMT"));
		return result;
	}
}
